Tuned Flame Shock conditions
Taracque [10-18-14 - 10:35]
Tuned Flame Shock conditions
diff --git a/modules/elemental.lua b/modules/elemental.lua
index 3acbc58..24ff341 100755
--- a/modules/elemental.lua
+++ b/modules/elemental.lua
@@ -181,15 +181,15 @@ Elementarist.elemental = {
end
end
- -- Earth shock if Lightning Shield count >=14 and not on cd, and FS debuff remaining > FS cooldown, or FS debuff remaining between FS and FS cd + 2sec and LS count>=5
+ -- Earth shock if Lightning Shield count >=12 and not on cd, and FS debuff remaining > FS cooldown, or FS debuff remaining between FS and FS cd + 2sec and LS count>=10
if ( (exspell1 ~= Elementarist.SpellList["Earth Shock"]) and (exspell2 ~= Elementarist.SpellList["Earth Shock"]) and (exspell1 ~= Elementarist.SpellList["Flame Shock"]) and (exspell2 ~= Elementarist.SpellList["Flame Shock"]) ) then
if ( (fsExpiration - GetTime() - timeshift) > Elementarist.lastShockCD ) then
d = Elementarist:GetSpellCooldownRemaining(Elementarist.SpellList["Earth Shock"])
local _, _, _, lscount = Elementarist:hasBuff("player",Elementarist.SpellList["Lightning Shield"])
if (
( (d) and ((d-timeshift) <= 0) and (lscount) ) and ( -- Earth Shock is available, and has lightning shield
- (lscount>=14) or -- Lightning shield has 14 charge
- ( (lscount>=12) and ( (fsExpiration - GetTime() - timeshift) < Elementarist.lastShockCD + 2 ) ) -- or, has 12 or more charges but FS expiration within 2 secs to FS CD
+ (lscount>=12) or -- Lightning shield has 12 charge
+ ( (lscount>=10) and ( (fsExpiration - GetTime() - timeshift) < Elementarist.lastShockCD + 2 ) ) -- or, has 10 or more charges but FS expiration within 2 secs to FS CD
)
) then
return Elementarist.SpellList["Earth Shock"]